#!/bin/bash

cfgfile_2g=/etc/router/config/wireless_2g.json

start_wireless_2g() {
	local ifname=$1
	enabled=`cat ${cfgfile_2g} | jq -r .enabled`
	ssid=`cat ${cfgfile_2g} | jq -r .ssid`
	encryption=`cat ${cfgfile_2g} | jq -r .encryption`
	key=`cat ${cfgfile_2g} | jq -r .key`

	local hostapd_cfgpath=/etc/router/tmp/hostapd.conf-${ifname}
	proc=`ps -ef | grep ${hostapd_cfgpath} | grep -v grep | awk '{print $2}'`
	if [[ -n ${proc} ]]; then
		kill -9 ${proc}
	fi

	if [[ ${enabled} == 0 ]]; then
		echo "wireless 2g disabled!"
		return
	fi
	
	cat > ${hostapd_cfgpath} << EOF
driver=nl80211
hw_mode=g
wmm_enabled=1
bridge=br0
ieee80211n=1
ht_capab=[HT40+][LDPC][SHORT-GI-20][SHORT-GI-40][TX-STBC][RX-STBC1][MAX-AMSDU-7935][DSSS_CCK-40]
channel=0
country_code=CN
auth_algs=1
wpa_key_mgmt=WPA-PSK
wpa_pairwise=CCMP
wpa=${encryption}
interface=${ifname}
ssid=${ssid}
wpa_passphrase=${key}
EOF
	
	for i in {1..5}
	do
		hostapd -B ${hostapd_cfgpath}
		sleep 1
		proc=`ps -ef | grep ${hostapd_cfgpath} | grep -v grep | awk '{print $2}'`
		if [[ -n ${proc} ]]; then
			break
		fi
	done
}

scan_wireless_dev() {

	netdevs=`ls /sys/class/net/ | grep -v "$(ls /sys/devices/virtual/net/)"`
	for netdev in ${netdevs[@]}
	do
		wireless_dir="/sys/class/net/"${netdev}"/wireless"
		if [[ -d ${wireless_dir} ]]; then
			support_5g=`iwlist ${netdev} channel | grep "Channel 36"`
			if [[ -z ${support_5g} ]]; then
				start_wireless_2g ${netdev}
			fi
		fi
	done
}

scan_wireless_dev
exit 0