#!/bin/bash

cfgfile_5g=/etc/router/config/wireless_5g.json

start_wireless_5g() {
	local ifname=$1
	enabled=`cat ${cfgfile_5g} | jq -r .enabled`
	ssid=`cat ${cfgfile_5g} | jq -r .ssid`
	encryption=`cat ${cfgfile_5g} | jq -r .encryption`
	key=`cat ${cfgfile_5g} | jq -r .key`

	hostapd_cfgpath=/etc/router/tmp/hostapd.conf-${ifname}
	proc=`ps -ef | grep ${hostapd_cfgpath} | grep -v grep | awk '{print $2}'`
	if [[ -n ${proc} ]]; then
		kill -9 ${proc}
		sleep 0.5
	fi

	if [[ ${enabled} == 0 ]]; then
		echo "wireless 5g disabled!"
		return
	fi
	
	cat > ${hostapd_cfgpath} << EOF
driver=nl80211
hw_mode=a
wmm_enabled=1
bridge=br0
ieee80211n=1
ht_capab=[HT40+][LDPC][SHORT-GI-20][SHORT-GI-40][TX-STBC][RX-STBC1][MAX-AMSDU-7935][DSSS_CCK-40]
ieee80211ac=1
vht_capab=[RXLDPC][SHORT-GI-80][SHORT-GI-160][TX-STBC-2BY1][SU-BEAMFORMER][SU-BEAMFORMEE][MU-BEAMFORMEE][RX-ANTENNA-PATTERN][TX-ANTENNA-PATTERN][RX-STBC-1][VHT160-80PLUS80][MAX-MPDU-11454][MAX-A-MPDU-LEN-EXP7]
vht_oper_chwidth=1
channel=0
#country_code=CN
auth_algs=1
wpa_key_mgmt=WPA-PSK
wpa_pairwise=CCMP
wpa=${encryption}
interface=${ifname}
ssid=${ssid}
wpa_passphrase=${key}
EOF
		
	for i in {1..5}
	do
		hostapd -B ${hostapd_cfgpath}
		sleep 1
		proc=`ps -ef | grep ${hostapd_cfgpath} | grep -v grep | awk '{print $2}'`
		if [[ -n ${proc} ]]; then
			break
		fi
	done
}

scan_wireless_dev() {

	netdevs=`ls /sys/class/net/ | grep -v "$(ls /sys/devices/virtual/net/)"`
	for netdev in ${netdevs[@]}
	do
		wireless_dir="/sys/class/net/"${netdev}"/wireless"
		if [[ -d ${wireless_dir} ]]; then
			support_5g=`iwlist ${netdev} channel | grep "Channel 36"`
			if [[ -n ${support_5g} ]]; then
				start_wireless_5g ${netdev}
			fi
		fi
	done
}

scan_wireless_dev
exit 0